# google-ads-report

[![release](https://img.shields.io/pypi/v/google-ads-report.svg)](https://pypi.org/project/google-ads-report/)
[![docs](https://img.shields.io/website/https/ikameglobal.github.io/google-ads-report/index.html.svg?label=docs&down_message=unavailable&up_message=available)](https://ikameglobal.github.io/google-ads-report)
[![develop](https://github.com/ikameglobal/google-ads-report/actions/workflows/dev.yml/badge.svg)](https://github.com/ikameglobal/google-ads-report/actions/workflows/dev.yml)
[![main](https://github.com/ikameglobal/google-ads-report/actions/workflows/release.yml/badge.svg)](https://github.com/ikameglobal/google-ads-report/actions/workflows/release.yml)

Easier to use

## Features

* Get report from Google Ads API in Stream
* Something else
